==> stoics_lib-2.0.tgz: stoics_lib/src/LibIndex.pl <==
lib_index(arg_add, 4, any, user, 'term/arg_add').
lib_index(arg, 4, any, user, 'term/arg').
lib_index(arg, 5, any, user, 'term/arg').
lib_index(arity, 3, any, user, 'term/arity').
lib_index(arity, 2, any, user, 'term/arity').
lib_index(at_con, 2, any, user, 'atom/at_con').
lib_index(at_con, 3, any, user, 'atom/at_con').
lib_index(atom_replace, 4, any, user, 'atom/atom_replace').
lib_index(atom_sub, 2, any, user, 'atom/atom_sub').
lib_index(break_on_list, 4, any, user, 'list/break_on_list').
lib_index(break_nth, 4, any, user, 'list/break_nth').
lib_index(call_morph, 4, any, user, 'meta/call_morph').
lib_index(colour_hex, 2, any, user, 'colour/colour_hex').
lib_index(compound, 3, any, user, 'term/compound').
lib_index(compare, 4, any, user, 'term/compare').
lib_index(compare_arithmetic, 3, any, user, 'number/compare_arithmetic').
lib_index(current_call, 1, any, user, 'meta/current_call').
lib_index(current_call, 2, any, user, 'meta/current_call').
lib_index(curtail, 3, any, user, 'term/curtail').
lib_index(datime_readable, 1, any, user, 'date_time/datime_readable').
lib_index(datime_readable, 2, any, user, 'date_time/datime_readable').
lib_index(date_two_digit_dotted, 1, any, user, 'date_time/date_two_digit_dotted').
lib_index(date_two_digit_dotted, 2, any, user, 'date_time/date_two_digit_dotted').
lib_index(day_trailer, 2, any, user, 'date_time/day_trailer').
lib_index(get_date, 1, any, user, 'date_time/get_date').
lib_index(get_date_time, 1, any, user, 'date_time/get_date_time').
lib_index(has_at_least, 3, any, user, 'list/has_at_least').
lib_index(has_at_most, 3, any, user, 'list/has_at_most').
lib_index(has_cased, 3, any, user, 'codes/has_cased').
lib_index(has_length, 2, any, user, 'term/has_length').
lib_index(has_length, 3, any, user, 'term/has_length').
lib_index(has_length, 4, any, user, 'term/has_length').
lib_index(en_append, 3, any, user, 'list/en_append').
lib_index(en_list, 2, any, user, 'term/en_list').
lib_index(expand_spec, 2, any, user, 'file/expand_spec').
lib_index(functor_term, 2, any, user, 'term/functor_term').
lib_index(get_datetime, 1, any, user, 'date_time/get_datetime' ).
lib_index(goal, 4, any, user, 'meta/goal').
lib_index(goal_spec, 2, any, user, 'meta/goal_spec').
lib_index(holds, 2, any, user, 'meta/holds').
lib_index(int_trailer, 2, any, user, 'number/int_trailer').
lib_index(imported_from, 2, any, user, 'meta/imported_from').
lib_index(io_close, 2, any, user, 'io/io_close').
lib_index(io_get_line, 2, any, user, 'io/io_get_line').
lib_index(io_line, 2, any, user, 'io/io_line').
lib_index(io_lines, 2, any, user, 'io/io_lines').
lib_index(io_open, 3, any, user, 'io/io_open').
lib_index(io_put_line, 2, any, user, 'io/io_put_line').
lib_index(io_sections, 3, any, user, 'io/io_sections').
lib_index(io_streams, 3, any, user, 'io/io_streams').
lib_index(io_url, 1, any, user, 'io/io_url').
lib_index(known, 1, any, user, 'meta/known').
lib_index(known, 2, any, user, 'meta/known').
lib_index(known, 3, any, user, 'meta/known').
lib_index(kv_compose, 3, any, user, 'kv/kv_compose').
lib_index(kv_compose, 4, any, user, 'kv/kv_compose').
lib_index(kv_decompose, 3, any, user, 'kv/kv_decompose').
lib_index(kv_ks, 2, any, user, 'kv/kv_ks').
lib_index(kv_transpose, 2, any, user, 'kv/kv_transpose').
lib_index(kv_vs, 2, any, user, 'kv/kv_vs').
lib_index(kvo_k_memberchk, 3, any, user, 'kv/kvo_k_memberchk').
lib_index(kvs_k_memberchk, 3, any, user, 'kv/kvs_k_memberchk').
lib_index(latex_colour, 4, any, user, 'colour/latex_colour').
lib_index(letter_strings, 3, any, user, 'string/letter_strings').
lib_index(lexi, 2, any, user, 'codes/lexi').
lib_index(lexi_n, 4, any, user, 'codes/lexi_n').
lib_index(list_frequency, 2, any, user, 'list/list_frequency').
lib_index(list_frequency, 3, any, user, 'list/list_frequency').
lib_index(list_is_invariant, 1, any, user, 'list/list_is_invariant').
lib_index(list_proportions, 2, any, user, 'list/list_proportions').
lib_index(list_proportions, 3, any, user, 'list/list_proportions').
lib_index(list_transpose, 2, any, user, 'list/list_transpose').
lib_index(locate, 3, any, user, 'file/locate').
lib_index(min_max, 3, any, user, 'list/min_max').
lib_index(maparg, 2, any, user, 'meta/maparg').
lib_index(maparg, 3, any, user, 'meta/maparg').
lib_index(maparg, 4, any, user, 'meta/maparg').
lib_index(map_succ_list, 3, any, user, 'meta/map_succ_list').
lib_index(map_succ_list, 4, any, user, 'meta/map_succ_list').
lib_index(map_list_options, 3, any, user, 'meta/map_list_options').
lib_index(map_list_options, 4, any, user, 'meta/map_list_options').
lib_index(message_report, 3, any, user, 'error/message_report').
lib_index(mod_goal, 2, any, user, 'meta/mod_goal').
lib_index(mod_goal, 3, any, user, 'meta/mod_goal').
lib_index(mod_goal, 4, any, user, 'meta/mod_goal').
lib_index(n_breaks, 4, any, user, 'list/n_breaks').
lib_index(n_digits_integer_codes, 3, any, user, 'codes/n_digits_integer_codes').
lib_index(n_digits_min, 3, any, uer, 'number/n_digits_min' ).
lib_index(nth1, 5, any, user, 'list/nth1' ).
lib_index(on_call, 4, any, user, 'meta/on_call').
lib_index(on_fail, 2, any, user, 'meta/on_fail').
lib_index(on_fail, 3, any, user, 'meta/on_fail').
lib_index(op_compare, 3, any, user, 'term/op_compare').
lib_index(portray_clauses, 2, any, user, 'term/portray_clauses').
lib_index(position, 3, any, user, 'term/position').
lib_index(position, 4, any, user, 'term/position').
lib_index(position, 6, any, user, 'term/position').
lib_index(position_nth, 3, any, user, 'term/position_nth').
lib_index(position_nth, 4, any, user, 'term/position_nth').
lib_index(position_type, 2, any, user, 'term/position_type').
lib_index(positions, 2, any, user, 'term/positions').
lib_index(positions, 3, any, user, 'term/positions').
lib_index(prefix_atom, 2, any, user, 'atom/prefix_atom').
lib_index(prefix_atom, 3, any, user, 'atom/prefix_atom').
lib_index(select_all, 3, any, user, 'list/select_all').
lib_index(select_all, 4, any, user, 'list/select_all').
lib_index(select_first, 3, any, user, 'list/select_first').
lib_index(skim, 3, any, user, 'list/skim').
lib_index(stoics_lib, 0, any, user, 'auxil/stoics_lib_module').
lib_index(stoics_lib_throw, 2, any, user, 'error/stoics_lib_throw').
lib_index(stoics_lib_version, 2, any, user, 'auxil/stoics_lib_module').
lib_index(sub_atom, 2, any, user, 'atom/sub_atom').
lib_index(sub_atom, 4, any, user, 'atom/sub_atom').
lib_index(three_letter_months, 1, any, user, 'date_time/three_letter_months').
lib_index(three_letter_month, 2, any, user, 'date_time/three_letter_month').
lib_index(term_length, 2, any, user, 'term/term_length').
lib_index(term_type, 2, any, user, 'term/term_type').
lib_index(termplate, 2, any, user, 'term/termplate').
lib_index(termplate, 3, any, user, 'term/termplate').
lib_index(url_file, 2, any, user, 'web/url_file').
lib_index(url_file, 3, any, user, 'web/url_file').
lib_index(which, 3, any, user, 'meta/which').

==> stoics_lib-2.1.tgz: stoics_lib/src/LibIndex.pl <==
lib_index(arg_add, 4, any, user, 'term/arg_add').
lib_index(arg, 4, any, user, 'term/arg').
lib_index(arg, 5, any, user, 'term/arg').
lib_index(arity, 3, any, user, 'term/arity').
lib_index(arity, 2, any, user, 'term/arity').
lib_index(at_con, 2, any, user, 'atom/at_con').
lib_index(at_con, 3, any, user, 'atom/at_con').
lib_index(atom_replace, 4, any, user, 'atom/atom_replace').
lib_index(atom_sub, 2, any, user, 'atom/atom_sub').
lib_index(break_on_list, 4, any, user, 'list/break_on_list').
lib_index(break_nth, 4, any, user, 'list/break_nth').
lib_index(call_morph, 4, any, user, 'meta/call_morph').
lib_index(colour_hex, 2, any, user, 'colour/colour_hex').
lib_index(compound, 3, any, user, 'term/compound').
lib_index(compare, 4, any, user, 'term/compare').
lib_index(compare_arithmetic, 3, any, user, 'number/compare_arithmetic').
lib_index(current_call, 1, any, user, 'meta/current_call').
lib_index(current_call, 2, any, user, 'meta/current_call').
lib_index(curtail, 3, any, user, 'term/curtail').
lib_index(datime_readable, 1, any, user, 'date_time/datime_readable').
lib_index(datime_readable, 2, any, user, 'date_time/datime_readable').
lib_index(date_two_digit_dotted, 1, any, user, 'date_time/date_two_digit_dotted').
lib_index(date_two_digit_dotted, 2, any, user, 'date_time/date_two_digit_dotted').
lib_index(day_trailer, 2, any, user, 'date_time/day_trailer').
lib_index(even, 1, any, user, 'number/even').
lib_index(get_date, 1, any, user, 'date_time/get_date').
lib_index(get_date_time, 1, any, user, 'date_time/get_date_time').
lib_index(has_at_least, 3, any, user, 'list/has_at_least').
lib_index(has_at_most, 3, any, user, 'list/has_at_most').
lib_index(has_cased, 3, any, user, 'codes/has_cased').
lib_index(has_length, 2, any, user, 'term/has_length').
lib_index(has_length, 3, any, user, 'term/has_length').
lib_index(has_length, 4, any, user, 'term/has_length').
lib_index(en_append, 3, any, user, 'list/en_append').
lib_index(en_list, 2, any, user, 'term/en_list').
lib_index(expand_spec, 2, any, user, 'file/expand_spec').
lib_index(functor_term, 2, any, user, 'term/functor_term').
lib_index(get_datetime, 1, any, user, 'date_time/get_datetime' ).
lib_index(goal, 4, any, user, 'meta/goal').
lib_index(goal_spec, 2, any, user, 'meta/goal_spec').
lib_index(holds, 2, any, user, 'meta/holds').
lib_index(int_trailer, 2, any, user, 'number/int_trailer').
lib_index(imported_from, 2, any, user, 'meta/imported_from').
lib_index(io_close, 2, any, user, 'io/io_close').
lib_index(io_get_line, 2, any, user, 'io/io_get_line').
lib_index(io_line, 2, any, user, 'io/io_line').
lib_index(io_lines, 2, any, user, 'io/io_lines').
lib_index(io_open, 3, any, user, 'io/io_open').
lib_index(io_put_line, 2, any, user, 'io/io_put_line').
lib_index(io_section, 3, any, user, 'io/io_section').
lib_index(io_section_close, 1, any, user, 'io/io_sections').
lib_index(io_section_open, 3, any, user, 'io/io_sections').
lib_index(io_sections, 3, any, user, 'io/io_sections').
lib_index(io_streams, 3, any, user, 'io/io_streams').
lib_index(io_url, 1, any, user, 'io/io_url').
lib_index(known, 1, any, user, 'meta/known').
lib_index(known, 2, any, user, 'meta/known').
lib_index(known, 3, any, user, 'meta/known').
lib_index(kv_compose, 3, any, user, 'kv/kv_compose').
lib_index(kv_compose, 4, any, user, 'kv/kv_compose').
lib_index(kv_decompose, 3, any, user, 'kv/kv_decompose').
lib_index(kv_ks, 2, any, user, 'kv/kv_ks').
lib_index(kv_transpose, 2, any, user, 'kv/kv_transpose').
lib_index(kv_vs, 2, any, user, 'kv/kv_vs').
lib_index(kvo_k_memberchk, 3, any, user, 'kv/kvo_k_memberchk').
lib_index(kvs_k_memberchk, 3, any, user, 'kv/kvs_k_memberchk').
lib_index(latex_colour, 4, any, user, 'colour/latex_colour').
lib_index(letter_strings, 3, any, user, 'string/letter_strings').
lib_index(lexi, 2, any, user, 'codes/lexi').
lib_index(lexi_n, 4, any, user, 'codes/lexi_n').
lib_index(list_frequency, 2, any, user, 'list/list_frequency').
lib_index(list_frequency, 3, any, user, 'list/list_frequency').
lib_index(list_is_invariant, 1, any, user, 'list/list_is_invariant').
lib_index(list_proportions, 2, any, user, 'list/list_proportions').
lib_index(list_proportions, 3, any, user, 'list/list_proportions').
lib_index(list_transpose, 2, any, user, 'list/list_transpose').
lib_index(locate, 3, any, user, 'file/locate').
lib_index(min_max, 3, any, user, 'list/min_max').
lib_index(maparg, 2, any, user, 'meta/maparg').
lib_index(maparg, 3, any, user, 'meta/maparg').
lib_index(maparg, 4, any, user, 'meta/maparg').
lib_index(map_succ_list, 3, any, user, 'meta/map_succ_list').
lib_index(map_succ_list, 4, any, user, 'meta/map_succ_list').
lib_index(map_list_options, 3, any, user, 'meta/map_list_options').
lib_index(map_list_options, 4, any, user, 'meta/map_list_options').
lib_index(message_report, 3, any, user, 'error/message_report').
lib_index(mod_goal, 2, any, user, 'meta/mod_goal').
lib_index(mod_goal, 3, any, user, 'meta/mod_goal').
lib_index(mod_goal, 4, any, user, 'meta/mod_goal').
lib_index(n_breaks, 4, any, user, 'list/n_breaks').
lib_index(n_digits_integer_codes, 3, any, user, 'codes/n_digits_integer_codes').
lib_index(n_digits_min, 3, any, uer, 'number/n_digits_min' ).
lib_index(nth1, 5, any, user, 'list/nth1' ).
lib_index(odd, 1, any, user, 'number/odd').
lib_index(on_call, 4, any, user, 'meta/on_call').
lib_index(on_fail, 2, any, user, 'meta/on_fail').
lib_index(on_fail, 3, any, user, 'meta/on_fail').
lib_index(op_compare, 3, any, user, 'term/op_compare').
lib_index(portray_clauses, 2, any, user, 'term/portray_clauses').
lib_index(position, 3, any, user, 'term/position').
lib_index(position, 4, any, user, 'term/position').
lib_index(position, 6, any, user, 'term/position').
lib_index(position_nth, 3, any, user, 'term/position_nth').
lib_index(position_nth, 4, any, user, 'term/position_nth').
lib_index(position_type, 2, any, user, 'term/position_type').
lib_index(positions, 2, any, user, 'term/positions').
lib_index(positions, 3, any, user, 'term/positions').
lib_index(prefix_atom, 2, any, user, 'atom/prefix_atom').
lib_index(prefix_atom, 3, any, user, 'atom/prefix_atom').
lib_index(select_all, 3, any, user, 'list/select_all').
lib_index(select_all, 4, any, user, 'list/select_all').
lib_index(select_first, 3, any, user, 'list/select_first').
lib_index(skim, 3, any, user, 'list/skim').
lib_index(stoics_lib, 0, any, user, 'auxil/stoics_lib_module').
lib_index(stoics_lib_throw, 2, any, user, 'error/stoics_lib_throw').
lib_index(stoics_lib_version, 2, any, user, 'auxil/stoics_lib_module').
lib_index(sub_atom, 2, any, user, 'atom/sub_atom').
lib_index(sub_atom, 4, any, user, 'atom/sub_atom').
lib_index(three_letter_months, 1, any, user, 'date_time/three_letter_months').
lib_index(three_letter_month, 2, any, user, 'date_time/three_letter_month').
lib_index(term_length, 2, any, user, 'term/term_length').
lib_index(term_type, 2, any, user, 'term/term_type').
lib_index(termplate, 2, any, user, 'term/termplate').
lib_index(termplate, 3, any, user, 'term/termplate').
lib_index(url_file, 2, any, user, 'web/url_file').
lib_index(url_file, 3, any, user, 'web/url_file').
lib_index(which, 3, any, user, 'meta/which').
